@@ -3,7 +3,7 @@
 # Copyright (C) 2008, Thomas Mashos <thomas@weilandhomes.com>
 # Copyright (C) 2008, Nick Fox <nfox@foxmediasystems.com>
 # This provides all the core features of Mythbuntu-Log-Grabber
-# 
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -22,74 +22,64 @@ import os
 import sys
 import subprocess
 import time
-from mythbuntu_common.logging import CustomLogging
+import logging
+import logging.handlers
 
-try:
- 	import pygtk
-  	pygtk.require("2.0")
-except:
-  	pass
 try:
 	import gtk
-  	import gtk.glade
+
 except:
 	sys.exit(1)
 
 class MythbuntuLogGrabber:
-	
+
 	log_path = os.path.join(os.getenv("HOME"), '.mythtv')
 	loglocation = os.path.join(log_path,"errorlogs.log")
-	err_log = "mythbuntu-log-grabber"
-	app_name = "Mythbuntu Log Grabber"
+	err_log = "/tmp/mythbuntu-log-grabber"
+	logging.basicConfig(filename=err_log,level=logging.DEBUG,)
+
 	if os.path.exists(loglocation):
 		os.remove(loglocation)
 	elif not os.path.exists(log_path):
 		try:
 			os.mkdir(log_path)
 		except IOError:
-			err_data = "An Exception occured while we tried to create the log gathering location."
-			if CustomLogging.check_path(err_log,log_path):
-				CustomLogging.append_log(app_name,err_log,log_path,err_data)
-			else:
-				CustomLogging.create_log(app_name,err_log,log_path,err_data)
+			logging.Debug('An Exception occured while we tried to create the log gathering location.')
 	SUBMITTED = False
 	GATHERED = False
-	
-		
+
+
 	def __init__(self):
 
-		
-		#Initialize GUI & Terminal
-		self.gladefile = "/usr/share/mythbuntu-log-grabber/SubmitWindow.glade"
-		self.wTree = gtk.glade.XML(self.gladefile, "MainWindow")
-		for widget in self.wTree.get_widget_prefix(""):
-			setattr(self, widget.get_name(), widget)
-			if isinstance(widget, gtk.Label):
-				widget.set_property('can-focus', False)
-		self.wTree.signal_autoconnect(self)
-	
-		#Get the Main Window, and connect the "destroy" event
-		self.window = self.wTree.get_widget("MainWindow")
-		if (self.window):
-			self.window.connect("destroy", gtk.main_quit)
 
-		#Create our dictionary and connect it
-		dic = { "on_btnlogs_clicked" : self.gather_logs_button_clicked,
-			"on_MainWindow_destroy" : gtk.main_quit }
-		self.wTree.signal_autoconnect(dic)
+		#Initialize GUI & Terminal
+		self.builder = gtk.Builder()
+		self.builder.add_from_file("/usr/share/mythbuntu-log-grabber/SubmitWindow.ui")
+
+		#make widgets referencable from top level
+		for widget in self.builder.get_objects():
+			if not isinstance(widget, gtk.Widget):
+				continue
+			setattr(self, widget.get_name(), widget)
+
+		#connect signals
+		self.builder.connect_signals(self)
+
+		#Get the Main Window, and connect the "destroy" event
+		self.builder.get_object("MainWindow").connect("destroy", gtk.main_quit)
 
 		if not self.GATHERED:
 			self.btnpost.set_sensitive(False)
 			self.btnview.set_sensitive(False)
 
-		self.statusbar = self.wTree.get_widget("statusbar")
+		self.statusbar = self.builder.get_object("statusbar")
 
 	def gather_logs_button_clicked(self, widget):
 		## Gather all the logs and ready them for submitting
 
 		self.SUBMITTED = False
 		self.GATHERED = True
-		
+
 		os.system("tail -n 100 /var/log/mythtv/*.log /var/log/syslog /var/log/Xorg.0.log ~/.xsession-errors > "+self.loglocation)
 
 		os.system('echo "" >> '+self.loglocation)
